@@ -1,5 +1,6 @@
 use crate::auditwheel::AuditWheelMode;
 use crate::build_options::CargoOptions;
+use crate::compression::CompressionOptions;
 use crate::target::detect_arch_from_python;
 use crate::BuildContext;
 use crate::BuildOptions;
@@ -39,6 +40,18 @@ impl InstallBackend {
 
     fn version(&self, python_path: &Path) -> Result<semver::Version> {
         let mut cmd = self.make_command(python_path);
+
+        // Newer versions of uv no longer support `uv pip --version`, and instead
+        // require that we use `uv --version`. This is a workaround to get the
+        // version of the install backend for both old and new versions of uv.
+        cmd = match self {
+            InstallBackend::Pip { .. } => cmd,
+            InstallBackend::Uv { path, args } => {
+                let mut cmd = Command::new(path);
+                cmd.args(args);
+                cmd
+            }
+        };
         let output = cmd
             .arg("--version")
             .output()
@@ -50,7 +63,7 @@ impl InstallBackend {
         let stdout = str::from_utf8(&output.stdout)?;
         let re = match self {
             InstallBackend::Pip { .. } => Regex::new(r"pip ([\w\.]+).*"),
-            InstallBackend::Uv { .. } => Regex::new(r"uv-pip ([\w\.]+).*"),
+            InstallBackend::Uv { .. } => Regex::new(r"uv ([\w\.]+).*"),
         };
         if let Some(captures) = re.expect("regex should be valid").captures(stdout) {
             Ok(semver::Version::parse(&captures[1])
@@ -217,6 +230,10 @@ pub struct DevelopOptions {
     /// Use `uv` to install packages instead of `pip`
     #[arg(long)]
     pub uv: bool,
+
+    /// Wheel compression options
+    #[command(flatten)]
+    pub compression: CompressionOptions,
 }
 
 #[instrument(skip_all)]
@@ -375,9 +392,12 @@ pub fn develop(develop_options: DevelopOptions, venv_dir: &Path) -> Result<()> {
         pip_path,
         cargo_options,
         uv,
+        compression,
     } = develop_options;
-    let mut target_triple = cargo_options.target.as_ref().map(|x| x.to_string());
-    let target = Target::from_target_triple(cargo_options.target)?;
+    compression.validate();
+
+    let mut target_triple = cargo_options.target.clone();
+    let target = Target::from_target_triple(cargo_options.target.as_ref())?;
     let python = target.get_venv_python(venv_dir);
 
     // check python platform and architecture
@@ -404,6 +424,7 @@ pub fn develop(develop_options: DevelopOptions, venv_dir: &Path) -> Result<()> {
             target: target_triple,
             ..cargo_options
         },
+        compression,
     };
 
     let build_context = build_options
