@@ -1,4 +1,5 @@
 //! The wheel format is (mostly) specified in PEP 427
+use crate::compression::{CompressionMethod, CompressionOptions};
 use crate::project_layout::ProjectLayout;
 use crate::target::Os;
 use crate::{
@@ -153,7 +154,11 @@ impl PathWriter {
             record_file.display()
         ))?;
 
-        for (filename, hash, len) in self.record {
+        // Sort records for deterministic output
+        let mut sorted_records = self.record.clone();
+        sorted_records.sort_by(|(path_a, _, _), (path_b, _, _)| path_a.cmp(path_b));
+
+        for (filename, hash, len) in sorted_records {
             buffer
                 .write_all(format!("{filename},sha256={hash},{len}\n").as_bytes())
                 .context(format!(
@@ -235,6 +240,27 @@ pub struct WheelWriter {
     wheel_path: PathBuf,
     file_tracker: FileTracker,
     excludes: Override,
+    compression: CompressionOptions,
+}
+impl CompressionOptions {
+    fn get_file_options(&self) -> zip::write::FileOptions<()> {
+        let method = if cfg!(feature = "faster-tests") {
+            // Unlike users which can use the develop subcommand, the tests have to go through
+            // packing a zip which pip than has to unpack. This makes this 2-3 times faster
+            CompressionMethod::Stored
+        } else {
+            self.compression_method
+        };
+
+        let mut options =
+            zip::write::SimpleFileOptions::default().compression_method(method.into());
+        // `zip` also has default compression levels, which should match our own, but we pass them
+        // explicitly to ensure consistency.
+        options = options.compression_level(Some(
+            self.compression_level.unwrap_or(method.default_level()),
+        ));
+        options
+    }
 }
 
 impl ModuleWriter for WheelWriter {
@@ -262,17 +288,11 @@ impl ModuleWriter for WheelWriter {
         // The zip standard mandates using unix style paths
         let target = target.to_str().unwrap().replace('\\', "/");
 
-        // Unlike users which can use the develop subcommand, the tests have to go through
-        // packing a zip which pip than has to unpack. This makes this 2-3 times faster
-        let compression_method = if cfg!(feature = "faster-tests") {
-            zip::CompressionMethod::Stored
-        } else {
-            zip::CompressionMethod::Deflated
-        };
+        let mut options = self
+            .compression
+            .get_file_options()
+            .unix_permissions(permissions);
 
-        let mut options = zip::write::SimpleFileOptions::default()
-            .unix_permissions(permissions)
-            .compression_method(compression_method);
         let mtime = self.mtime().ok();
         if let Some(mtime) = mtime {
             options = options.last_modified_time(mtime);
@@ -298,6 +318,7 @@ impl WheelWriter {
         metadata24: &Metadata24,
         tags: &[String],
         excludes: Override,
+        compression: CompressionOptions,
     ) -> Result<WheelWriter> {
         let wheel_path = wheel_dir.join(format!(
             "{}-{}-{}.whl",
@@ -315,6 +336,7 @@ impl WheelWriter {
             wheel_path,
             file_tracker: FileTracker::default(),
             excludes,
+            compression,
         };
 
         write_dist_info(&mut builder, metadata24, tags)?;
@@ -334,7 +356,7 @@ impl WheelWriter {
                 .normalize()
                 .with_context(|| {
                     format!(
-                        "failed to normalize python dir path `{}`",
+                        "python dir path `{}` does not exist or is invalid",
                         project_layout.python_dir.display()
                     )
                 })?
@@ -373,14 +395,7 @@ impl WheelWriter {
 
     /// Creates the record file and finishes the zip
     pub fn finish(mut self) -> Result<PathBuf, io::Error> {
-        let compression_method = if cfg!(feature = "faster-tests") {
-            zip::CompressionMethod::Stored
-        } else {
-            zip::CompressionMethod::Deflated
-        };
-
-        let mut options =
-            zip::write::SimpleFileOptions::default().compression_method(compression_method);
+        let mut options = self.compression.get_file_options();
         let mtime = self.mtime().ok();
         if let Some(mtime) = mtime {
             options = options.last_modified_time(mtime);
@@ -389,7 +404,12 @@ impl WheelWriter {
         let record_filename = self.record_file.to_str().unwrap().replace('\\', "/");
         debug!("Adding {}", record_filename);
         self.zip.start_file(&record_filename, options)?;
-        for (filename, hash, len) in self.record {
+
+        // Sort records for deterministic output
+        let mut sorted_records = self.record.clone();
+        sorted_records.sort_by(|(path_a, _, _), (path_b, _, _)| path_a.cmp(path_b));
+
+        for (filename, hash, len) in sorted_records {
             self.zip
                 .write_all(format!("{filename},sha256={hash},{len}\n").as_bytes())?;
         }
@@ -1085,7 +1105,7 @@ fn generate_uniffi_bindings(
     // when running uniffi-bindgen
     let binding_dir = target_dir
         .normalize()?
-        .join("maturin")
+        .join(env!("CARGO_PKG_NAME"))
         .join("uniffi")
         .join(module_name)
         .into_path_buf();
