@@ -27,10 +27,8 @@ fn develop_pyo3_pure() {
 }
 
 #[test]
-#[ignore]
 fn develop_pyo3_pure_conda() {
-    // Only run on GitHub Actions for now
-    if env::var("GITHUB_ACTIONS").is_ok() {
+    if which("conda").is_ok() {
         handle_result(develop::test_develop(
             "test-crates/pyo3-pure",
             None,
@@ -228,7 +226,7 @@ fn develop_hello_world(#[case] backend: TestInstallBackend, #[case] name: &str)
 }
 
 #[rstest]
-#[timeout(Duration::from_secs(60))]
+#[timeout(Duration::from_secs(120))]
 #[case(TestInstallBackend::Pip, "pip")]
 #[case(TestInstallBackend::Uv, "uv")]
 #[test]
@@ -362,8 +360,7 @@ fn integration_pyo3_mixed_src_layout() {
 #[test]
 #[cfg_attr(target_os = "macos", ignore)] // Don't run it on macOS, too slow
 fn integration_pyo3_pure_conda() {
-    // Only run on GitHub Actions for now
-    if env::var("GITHUB_ACTIONS").is_ok() {
+    if which("conda").is_ok() {
         handle_result(integration::test_integration_conda(
             "test-crates/pyo3-mixed",
             None,
@@ -540,7 +537,7 @@ fn integration_wasm_hello_world() {
 
 #[test]
 fn abi3_without_version() {
-    handle_result(errors::abi3_without_version())
+    handle_result(other::abi3_without_version())
 }
 
 #[test]
@@ -643,7 +640,7 @@ fn workspace_members_non_local_dep_sdist() {
         license = "MIT"
 
         [dependencies]
-        pyo3 = { version = "0.24.0", features = [
+        pyo3 = { version = "0.25.0", features = [
             "abi3-py37",
             "extension-module",
             "generate-import-lib",
@@ -712,7 +709,7 @@ fn lib_with_target_path_dep_sdist() {
         crate-type = ["cdylib"]
 
         [dependencies]
-        pyo3 = { version = "0.24.0", features = ["extension-module"] }
+        pyo3 = { version = "0.25.0", features = ["extension-module"] }
 
         [target.'cfg(not(target_endian = "all-over-the-place"))'.dependencies]
         some_path_dep = { path = "../some_path_dep" }
